module.exports = (pageName = 'Index', componentName, cptOrCpts = 'components') => `<template>
<div class="mainContent">
    <PathTracking />
    <el-row class="actionBtn">
        <!-- <c-button @click="createOrder" option="createOrder" type="slot"> -->
        <el-button @click="createOrder" type="primary">创建结算单</el-button>
        <!-- </c-button> -->
    </el-row>
    <div class="container">
        <div class="common-table-title">
            <div class="common-table-icon"></div>
            <div class="common-table-fl">查询条件</div>
        </div>
        <!-- 搜索框 -->
        <AdvancedSearch
            :option="filterOption"
            @getChild="getChild"
            @onSearch="getOrderList(1)"
            @onClear="onClear"
        />
        <!-- 表格 -->
        <div class="table">
            <el-row>
                <div class="common-table-title">
                    <div class="common-table-icon"></div>
                    <div class="common-table-fl">客户订单列表</div>
                    <div class="common-btn-group">
                        <div @click="exportOrder" class="common-table-btn-item">婚策订单导出</div>
                    </div>
                </div>
            </el-row>
            <el-row class="table-bg">
                <DisplayTable
                    ref="displayTable"
                    :loading="loading"
                    :tableData="tableData"
                    :optionList="optionList"
                    :selection="false"
                    :showIndex="true"
                    :pageHelper="listQuery"
                >
                    <template v-slot:before>
                        <el-table-column label="订单编号" align="center" fixed min-width="120">
                            <template slot-scope="{ row }">
                                <div class="detial-link" @click="toDetial(row)">{{ row.saleNumber }}</div>
                            </template>
                        </el-table-column>
                    </template>

                    <el-table-column label="排序" align="center" width="140">
                        <template slot-scope="{ row }">
                            <el-input-number
                                style="width: 120px"
                                v-model="row.sort"
                                :min="0"
                                :max="10000000"
                            ></el-input-number>
                        </template>
                    </el-table-column>

                    <el-table-column fixed="right" label="操作" width="120">
                        <template slot-scope="{ row }">
                            <div class="operate-btn" @click="edit(row)">编辑</div>
                        </template>
                    </el-table-column>
                </DisplayTable>
            </el-row>
            <PaginationCom
                :total="total"
                :page.sync="listQuery.pageIndex"
                :rows.sync="listQuery.pageSize"
                @pagination="getOrderList"
            />
        </div>
    </div>
    ${componentName ? `<${componentName} @getDataList="getDataList(1)" ref="${componentName}" />` : ''}
</div>
</template>

<script>
import { getDateString } from '@/assets/js/common.js';
import { filterOption, optionList } from './data';
import { downloadExcel, mapToList } from '@/utils/commonUtils';
import { getOrderList, getWeddingOrderStatus, getSaleMan, exportOrder } from './api.js';
${componentName ? `import ${componentName} from "./${cptOrCpts}/${componentName}.vue";` : ''}
export default {
    name: "${pageName}",
    components: {
        ${componentName ? `${componentName},` : ''}
    },
    data() {
        return {
            filterOption,
            optionList,
            tableData: [],
            loading: false,
            total: 0,
            listQuery: {
                pageIndex: 1,
                pageSize: 10
            },
            searchFromData: {}
        };
    },
    computed: {
        userInfo() {
            return this.$getUserInfo();
        }
    },
    watch: {},
    mounted() {
        // this.init();
    },
    activated() {
        this.init();
    },
    methods: {
        init() {
            this.getWeddingOrderStatus(); // 订单状态
            this.getSaleMan(); //获取销售人
            this.getOrderList(1);
        },
        edit(row) {
            this.$refs.${componentName}.show(row);
        },
        createOrder() {
            this.$refs.${componentName}.show();
        },
        async exportOrder() {
            this.$confirm('确认导出？', '提示').then(async () => {
                let res = await exportOrder({
                    condition: this.searchFromData || {},
                    ...this.listQuery
                });
                downloadExcel(res.data, '婚策订单.xls');
                this.$message.success('导出成功!');
            });
        },
        toDetial(row) {
            let { id, saleNumber } = row;
            this.$router.push({
                name: 'wpOrderDetail',
                query: {
                    id,
                    saleNumber
                }
            });
        },
        formatterList(obj = {}) {
            let arr = [];
            for (let item in obj) {
                let { value, key } = obj[item];
                arr.push({
                    label: value,
                    value: key
                });
            }
            return arr;
        },
        async getWeddingOrderStatus(type) {
            let res = await getWeddingOrderStatus();
            let weddingOrderStatusList = this.formatterList(res);
            let itemObj = this.filterOption.items.find(item => item.key == 'orderStatus');
            itemObj.data = weddingOrderStatusList;
            itemObj.value = undefined;
        },
        //获取销售人
        async getSaleMan() {
            let shopCode = this.userInfo.shopCode;
            let res = await getSaleMan(shopCode);
            let saleManList = res.map(item => {
                let { userName, jobNo, sapUserId } = item;
                return {
                    label: userName + '【' + jobNo + '】',
                    value: sapUserId
                };
            });
            let salesmanItem = this.filterOption.items.find(item => item.key == 'salesman');
            salesmanItem.data = saleManList;
            salesmanItem.value = undefined;
        },
        //获订单列表
        async getOrderList(pageIndex) {
            if (pageIndex) {
                this.listQuery.pageIndex = pageIndex;
            }
            this.loading = true;
            let params = this.searchFromData || {};
            let res = await getOrderList({
                condition: params,
                ...this.listQuery
            });
            let { total, result } = res;
            this.total = total;
            if (total == 0) {
                result = [];
            }
            result = result.map(item => ({
                ...item,
                sort: 0,
                testStr: "<div style='color:red'>hello world</div>"
            }));
            this.loading = false;
            this.tableData = result;
        },
        getChild(val) {
            //查询条件输入后的回调
            let obj = _.cloneDeep(val);
            if (val.shopAuxiliary) {
                obj.shopAuxiliary = val.shopAuxiliary[1];
            }
            if (val.creatTime) {
                obj.bookOrderStartTime = getDateString(new Date(val.creatTime[0]));
                obj.bookOrderEndTime = getDateString(new Date(val.creatTime[1]));
            }
            delete obj.creatTime;
            this.searchFromData = _.cloneDeep(obj);
        },
        onClear() {
            this.searchFromData = {};
        }
    }
};
</script>

<style scoped lang="less">
.container {
background-color: #f3f3f3;
padding: 0 16px 16px;
}

.table {
padding: 10px 0;
}
</style>`