module.exports = (componentName) => `<template>
<DialogCom ref="dialog" :title="isEdit ? '编辑' : '创建' + '结算单'" width="600px" :closeEnvent="closeEnvent">
    <el-form :model="myForm" :rules="formRule" ref="myForm" size="small" class="myForm" label-width="100px">
        <el-form-item label="供应商:" prop="supplierNo">
            <el-select
                v-model="myForm.supplierNo"
                filterable
                collapse-tags
                placeholder="请选择"
                style="width: 260px"
            >
                <el-option v-for="item in supplierList" :key="item.value" :label="item.label" :value="item.value" />
            </el-select>
        </el-form-item>
        <el-form-item label="币种:" prop="currency">
            <el-select v-model="myForm.currency" filterable collapse-tags placeholder="请选择" style="width: 260px">
                <el-option v-for="item in currencyList" :key="item.value" :label="item.label" :value="item.value" />
            </el-select>
        </el-form-item>

        <el-form-item label="结算周期:" prop="myDateTime">
            <el-date-picker
                style="width: 260px"
                v-model="myForm.myDateTime"
                type="datetimerange"
                :default-time="['00:00:00', '23:59:59']"
                value-format="yyyy-MM-dd HH:mm:ss"
                format="yyyy-MM-dd"
                range-separator="至"
                start-placeholder="开始日期"
                end-placeholder="结束日期"
                :picker-options="pickerOptionsStart"
            ></el-date-picker>
        </el-form-item>
    </el-form>
    <div class="dialog-footer">
        <el-button size="small" @click="close">关闭</el-button>
        <el-button size="small" class="customSureBtn" type="primary" @click="save">确定</el-button>
    </div>
</DialogCom>
</template>

<script>
import { debounce } from 'lodash';
import { createSettlement } from '../api.js';
export default {
  name: '${componentName}',
  props: {},
  data() {
      return {
          isEdit: false,
          supplierList: [
              {
                  value: 1,
                  label: '供应商1'
              },
              {
                  value: 2,
                  label: '供应商2'
              }
          ],
          currencyList: [
              {
                  lable: 'CNY',
                  value: 'CNY'
              },
              {
                  lable: 'HKD',
                  value: 'HKD'
              },
              {
                  lable: 'USD',
                  value: 'USD'
              }
          ],
          myForm: {
              supplierNo: '',
              myDateTime: [],
              currency: ''
          },
          formRule: {
              supplierNo: [{ required: true, message: '请选择供应商', trigger: 'change' }],
              currency: [{ required: true, message: '请选择币种', trigger: 'change' }],
              myDateTime: [{ required: true, message: '请选择结算周期', trigger: 'change' }]
          },
          pickerOptionsStart: {
              disabledDate: time => {
                  return time.getTime() < new Date().getTime();
              }
          }
      };
  },

  async mounted() {},
  methods: {
      closeEnvent() {
          this.reset();
      },
      save: debounce(function () {
          this.$refs['myForm'].validate(async valid => {
              if (valid) {
                  let { supplierNo, myDateTime = [], currency } = this.myForm;
                  let params = {
                      supplierNo: supplierNo,
                      currency: currency,
                      settlementStart: myDateTime[0],
                      settlementEnd: myDateTime[1]
                  };
                  //创建or编辑
                  this.isEdit ? await createSettlement(params) : await createSettlement(params);
                  this.$message.success((this.isEdit ? '编辑' : '创建') + '结算单成功！');
                  this.$emit('getDataList');
                  this.close();
              } else {
                  return false;
              }
          });
      }, 600),
      reset() {
          Object.assign(this.$data, this.$options.data());
      },
      close() {
          this.$refs['dialog'].close();
      },
      show(params = {}) {
          this.myForm = { ...params };
          this.isEdit = Object.keys(params).length > 0;
          this.$refs['dialog'].show();
      }
  }
};
</script>

<style rel="stylesheet/scss" lang="less" scoped></style>
`